@@ -4,7 +4,7 @@
 //  DFT based HighPass filter controller
 //
 //  Created by Riccardo Mottola on Mon Oct 13 2003.
-//  Copyright (c) 2003 Carduus. All rights reserved.
+//  Copyright (c) 2003-2010 Carduus. All rights reserved.
 //
 // This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
@@ -12,13 +12,15 @@
 
 #import <AppKit/AppKit.h>
 
+#import "PRFilterController.h"
 
-@interface PRCDFTHighPass : NSObject
+
+@interface PRCDFTHighPass : PRFilterController
 {
-    IBOutlet NSWindow *filterWindow;
-    IBOutlet NSButton *autoRangeCheck;
-    IBOutlet NSSlider *passBandSlider;
-    IBOutlet NSSlider *stopBandSlider;
+    IBOutlet NSWindow    *filterWindow;
+    IBOutlet NSButton    *autoRangeCheck;
+    IBOutlet NSSlider    *passBandSlider;
+    IBOutlet NSSlider    *stopBandSlider;
     IBOutlet NSTextField *passBandVal;
     IBOutlet NSTextField *passBandValPi;
     IBOutlet NSTextField *stopBandVal;
@@ -28,9 +30,6 @@
     BOOL autoRange;
 }
 
-- (IBAction)showDFTHP:(id)sender;
-- (IBAction)dftHPOK:(id)sender;
-- (IBAction)dftHPCancel:(id)sender;
 - (IBAction)dftHPAutoRange:(id)sender;
 - (IBAction)changeStopBand:(id)sender;
 - (IBAction)changePassBand:(id)sender;
