@@ -4,43 +4,61 @@
 //  Grayscale Conversion Controller
 //
 //  Created by Riccardo Mottola on Tue Jan 16 2007.
-//  Copyright (c) 2007 Carduus. All rights reserved.
+//  Copyright (c) 2007-2010 Carduus. All rights reserved.
 //
 // This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 #import "PRCGrayscale.h"
 #import "PRGrayscaleFilter.h"
-#import "MyDocument.h"
 
 @implementation PRCGrayscale
 
-- (IBAction)showGrayscale:(id)sender
+- (id)init
 {
+    if ((self = [super init]))
+    {
+        filter = [[PRGrayscaleFilter alloc] init];
+    }
+    return self;
+}
+
+- (IBAction)showFilter:(id)sender
+{
+    [super showFilter:sender];
+
     if (!grayWindow)
         [NSBundle loadNibNamed:@"Grayscale" owner:self];
     [grayWindow makeKeyAndOrderFront:nil];
+
+    [self parametersChanged:self];
 }
 
-- (IBAction)grayscaleOK:(id)sender
+- (NSArray *)encodeParameters
 {
-    int index;
-    int method;
-
+    NSArray           *parameters;
+    int               index;
+    int               method;
+    
     index = [methodChoice indexOfSelectedItem];
     if (index == 0)
         method = METHOD_AVERAGE;
     else if (index == 1)
         method = METHOD_LUMINANCE;
+    
+    /* encode parameters */
+    parameters = [NSArray arrayWithObjects:
+        [NSNumber numberWithInt:method],
+        nil];
 
-    [[[NSDocumentController sharedDocumentController] currentDocument] makeGrayscale :method :nil];
-    if ([[NSApp delegate] prefClosePanels])
-        [grayWindow performClose:nil];
+    return parameters;
 }
 
-- (IBAction)grayscaleCancel:(id)sender
+- (void)closeFilterPanel
 {
     [grayWindow performClose:nil];
 }
 
+
+
 @end
