@@ -3,7 +3,7 @@
 //  PRICE
 //
 //  Created by Riccardo Mottola on Fri Dec 07 2007.
-//  Copyright (c) 2007 Carduus. All rights reserved.
+//  Copyright (c) 2007-2009 Carduus. All rights reserved.
 //
 // This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
@@ -14,6 +14,19 @@
 
 @implementation PRInvert
 
+- (PRImage *)filterImage:(PRImage *)image with:(NSArray *)parameters progressPanel:(PRCProgress *)progressPanel
+{
+
+    /* interpret the parameters */
+
+    return [self filterImage:image];
+}
+
+- (NSString *)actionName
+{
+    return @"Invert";
+}
+
 - (PRImage *)filterImage:(PRImage *)srcImage
 {
     NSBitmapImageRep *srcImageRep;
@@ -25,16 +38,21 @@
     unsigned char    *destData;
     unsigned char    *p1;
     unsigned char    *p2;
-    int              bytesPerPixel;
-
+    int              srcSamplesPerPixel;
+    int              destSamplesPerPixel;
+    int              srcBytesPerRow;
+    int              destBytesPerRow;
+    
 
     /* get source image representation and associated information */
-    srcImageRep = [srcImage tiffRep];
+    srcImageRep = [srcImage bitmapRep];
 
     w = [srcImageRep pixelsWide];
     h = [srcImageRep pixelsHigh];
-    bytesPerPixel = [srcImageRep bitsPerPixel] /8;
-
+    srcSamplesPerPixel = [srcImageRep samplesPerPixel];
+    destSamplesPerPixel = srcSamplesPerPixel;
+    srcBytesPerRow = [srcImageRep bytesPerRow];
+    
 
     /* allocate destination image and its representation */
     destImage = [[PRImage alloc] initWithSize:NSMakeSize(w, h)];
@@ -52,6 +70,8 @@
 
     srcData = [srcImageRep bitmapData];
     destData = [destImageRep bitmapData];
+    destSamplesPerPixel = [destImageRep samplesPerPixel];
+    destBytesPerRow = [destImageRep bytesPerRow];
 
     /* execute the actual filtering  */
     /* take in account if image has alpha and if it is has one or 3 samples */
@@ -62,16 +82,16 @@
             for (y = 0; y < h; y++)
                 for (x = 0; x < w; x++)
                 {
-                    p1 = srcData + bytesPerPixel * (y * w + x);
-                    p2 = destData + bytesPerPixel * (y * w + x);
+                    p1 = srcData + srcBytesPerRow * y + srcSamplesPerPixel * x;
+                    p2 = destData + destBytesPerRow * y + destSamplesPerPixel * x;
                     p2[0] = UCHAR_MAX - p1[0];
                 }
         else
             for (y = 0; y < h; y++)
                 for (x = 0; x < w; x++)
                 {
-                    p1 = srcData + bytesPerPixel * (y * w + x);
-                    p2 = destData + bytesPerPixel * (y * w + x);
+                    p1 = srcData + srcBytesPerRow * y + srcSamplesPerPixel * x;
+                    p2 = destData + destBytesPerRow * y + destSamplesPerPixel * x;
                     p2[0] = UCHAR_MAX - p1[0];
                     p2[1] = p1[1];
                 }
@@ -82,26 +102,32 @@
             for (y = 0; y < h; y++)
                 for (x = 0; x < w; x++)
                 {
-                    p1 = srcData + bytesPerPixel * (y * w + x);
-                    p2 = destData + bytesPerPixel * (y * w + x);
+                    p1 = srcData + srcBytesPerRow * y + srcSamplesPerPixel * x;
+                    p2 = destData + destBytesPerRow * y + destSamplesPerPixel * x;
                     p2[0] = UCHAR_MAX - p1[0];
                 }
         else
             for (y = 0; y < h; y++)
                 for (x = 0; x < w; x++)
                 {
-                    p1 = srcData + bytesPerPixel * (y * w + x);
-                    p2 = destData + bytesPerPixel * (y * w + x);
+                    p1 = srcData + srcBytesPerRow * y + srcSamplesPerPixel * x;
+                    p2 = destData + destBytesPerRow * y + destSamplesPerPixel * x;
                     p2[0] = UCHAR_MAX - p1[0];
                     p2[1] = UCHAR_MAX - p1[1];
                     p2[2] = UCHAR_MAX - p1[2];
                 }
     }
+                    
     [destImage addRepresentation:destImageRep];
     [destImageRep release];
     [destImage autorelease];
     return destImage;
 }
 
+- (BOOL)displayProgress
+{
+    return NO;
+}
+
 
 @end
